
*First, load the dataset "Empirical dataset.dta"
*Results are generated from line 200 onward.


*DEFINES SURVEY LEVEL INDICATOR
*considers 1 observation per survey instead of one observastion per 3 years of balance sheet data of a firm present in one survey
tsset firm indagine
gen indagine_temp=round(((firm/10)-round(firm/10))*10)
gen indagine2=indagine if (indagine==indagine_temp)
gen firm2=round(firm/10)
gen firm2_indagine2=firm2+indagine2/10
bysort firm: egen indagine2_full=mean(indagine2)
gen aux=indagine2!=.
bysort firm2: egen nobs_per_firm=sum(aux)
drop aux


display "**************************************************"
display "number of firm survey observations"
display "**************************************************"
tabulate nobs_per_firm if indagine2!=.


**************************************************
****** PART I,  DATA PREPARATION  ****************
**************************************************


sort firm indagine
*MEASURES OF PERFORMANCE
*TFP: 
rename log_prod log_prod1
*LABOUR PRODUCTIVITY GROWTH
sort firm indagine
tsset firm indagine
gen aux2=log_prod4-l.log_prod4
gen log_prod_LP=log_prod4 if abs(aux2)<1.5
drop aux*
*EMPLOYMENT GROWTH
sort firm2 indagine2
tsset firm2 indagine2
gen aux=log(occupa)
gen aux2=aux-l.aux
summ aux2,det
gen log_prod_occ=aux if abs(aux2)<1.5 | aux2==.
drop aux*
*CAPITAL STOCK GROWTH
gen aux=log(totcap)
sort firm indagine
tsset firm indagine
gen aux2=aux-l.aux
summ aux2,det
gen log_cap=aux if abs(aux2)<1.5 
count if abs(aux2)<1.5
drop aux*

*FINANCING CONSTRAINTS MEASURES
*MEASURE 1: ONE FOR EACH FIRM-SURVEY OBSRVATION WITH ANY PROBLEM DECLARED. ZERO FOR EACH FIRM SURVEY OBSERVATION WITHOUT ANY PROBLEM DECLARED
bysort firm: egen profits_firm_orig=mean(reddito_operativo/ valore_aggiunto)
gen profits_firm=profits_firm_orig
bysort firm2_indagine2: egen aux=sum(binding)
gen binding_firm_M1=(aux>0)*(profits_firm_orig>0.1) 
gen binding_firm_raw=(aux>0) 
gen control1=indagine2_full!=1 & indagine2_full!=. 
drop aux
*MEASURE 2: 1-3 FOR EACH FIRM-SUVEY OBSERVATION ADDING UP PROBLEMS DECLARED
gen aux0=bind1+bind2+bind3
bysort firm2_indagine2: egen aux=sum(aux0)
gen binding_firm_M2=(aux)*(profits_firm_orig>0.1) /*this is one if the firm at any point had at least one declared f. frict.*/
gen control2=indagine2_full!=.
drop aux0 aux
*MEASURE 3: ONLY BIND 1 - 
bysort firm2_indagine2: egen aux=sum(bind1)
gen binding_firm_M3=(aux>0)*(profits_firm_orig>0.1) /*this is one if the firm at any point had at least one declared f. frict.*/
gen control3=indagine2_full!=.
drop aux
*MEASURE 4: only surveys 3 and 4, composite
gen aux0=bind1+0.5*bind2+0.5*bind3
bysort firm2_indagine2: egen aux=sum(aux)
gen binding_firm_M4=(aux)*(profits_firm_orig>0.1) /*this is one if the firm at any point had at least one declared f. frict.*/
gen control4=indagine2_full!=2 & indagine2_full!=.
drop aux0 aux
gen binding_firm=binding_firm_M1
*MEASURE 5: External financial dependence
bysort firm: gen EFD=(capital_ch-cashflow)/capital_ch if binding_firm==0 & capital_ch!=.
summ EFD,det
bysort ateco4: egen aux3=mean(EFD) if EFD>`r(p5)' & EFD<`r(p95)'
gen EFD_dig4=aux3 
gen control9=indagine2_full!=.
cap drop aux* 
*MEASURE 6: using pbinding (probability of being constrained)
gen binding_firm_M12=pbinding 
gen control12=pbinding!=.

gen age_pos_sq=age_pos^2
gen age=age_pos


*Generate the frequency of constrained firms for all
foreach i in 1 2 3 4{
display `i'
by ateco4: egen dig4_num=count(binding_firm_M`i'!=.) if firm2_indagine2!=.  & control`i'==1
by ateco4: egen aux1=mean(binding_firm_M`i') if firm2_indagine2!=.  & control`i'==1 & dig4_num>9
by ateco4: egen aux2=mean(aux1)  if control`i'==1
summ aux2,det
gen binding_freq_dig4_`i'=aux2 if aux2>`r(p1)' & aux2<`r(p99)'
egen aux3=pctile(binding_freq_dig4_`i'), p(50)
egen aux4=pctile(binding_freq_dig4_`i'), p(33)
egen aux5=pctile(binding_freq_dig4_`i'), p(66)
gen constr`i'= binding_freq_dig4_`i'>aux3 if binding_freq_dig4_`i'!=. & control`i'==1
gen mconstr`i'= binding_freq_dig4_`i'>aux5 if binding_freq_dig4_`i'!=. & control`i'==1
gen midconstr`i'= binding_freq_dig4_`i'>aux4 & binding_freq_dig4_`i'<=aux5  if binding_freq_dig4_`i'!=. & control`i'==1
gen lconstr`i'= binding_freq_dig4_`i'<aux4 if binding_freq_dig4_`i'!=. & control`i'==1

gen age_pos_constr`i'=age_pos*constr`i'
gen indagine_constr`i'=indagine*constr`i'

gen age_pos_midc`i'=age_pos*midconstr`i'
gen age_pos_mconstr`i'=age_pos*mconstr`i'
gen indagine_midc`i'=indagine*midconstr`i'
gen indagine_mconstr`i'=indagine*mconstr`i'

gen age_pos_freqc`i'=age_pos*binding_freq_dig4_`i'
gen age_pos_freqc_sq`i'=age_pos*(binding_freq_dig4_`i'^2)

drop aux1 aux2 aux3 aux4 aux5 dig4_num
}

foreach i in 9 {
display `i'
by ateco4: egen dig4_num=count(EFD_dig4!=.) if control`i'==1
by ateco4: egen aux1=mean(EFD_dig4) if  control`i'==1 
by ateco4: egen aux2=mean(aux1)  if control`i'==1
summ aux2,det
gen binding_freq_dig4_`i'=aux2 
egen aux3=pctile(binding_freq_dig4_`i'), p(50)
egen aux4=pctile(binding_freq_dig4_`i'), p(33)
egen aux5=pctile(binding_freq_dig4_`i'), p(66)
gen constr`i'= binding_freq_dig4_`i'>aux3 if binding_freq_dig4_`i'!=. & control`i'==1
gen mconstr`i'= binding_freq_dig4_`i'>aux5 if binding_freq_dig4_`i'!=. & control`i'==1
gen midconstr`i'= binding_freq_dig4_`i'>aux4 & binding_freq_dig4_`i'<=aux5  if binding_freq_dig4_`i'!=. & control`i'==1

gen age_pos_constr`i'=age_pos*constr`i'
gen indagine_constr`i'=indagine*constr`i'

gen age_pos_midc`i'=age_pos*midconstr`i'
gen age_pos_mconstr`i'=age_pos*mconstr`i'
gen indagine_midc`i'=indagine*midconstr`i'
gen indagine_mconstr`i'=indagine*mconstr`i'

gen age_pos_freqc`i'=age_pos*binding_freq_dig4_`i'
gen age_pos_freqc_sq`i'=age_pos*(binding_freq_dig4_`i'^2)

drop aux1 aux2 aux3 aux4 aux5 dig4_num
}
foreach i in 12{
display `i'

by ateco4: egen dig4_num=count(binding_firm_M`i'!=.) if control`i'==1
by ateco4: egen aux1=mean(binding_firm_M`i') if control`i'==1 & dig4_num>9
by ateco4: egen aux2=mean(aux1) 

summ aux2,det
gen binding_freq_dig4_`i'=aux2 if aux2>`r(p1)' & aux2<`r(p99)'
egen aux3=pctile(binding_freq_dig4_`i'), p(50)
egen aux4=pctile(binding_freq_dig4_`i'), p(33)
egen aux5=pctile(binding_freq_dig4_`i'), p(66)
gen constr`i'= binding_freq_dig4_`i'>aux3 if binding_freq_dig4_`i'!=. 
gen mconstr`i'= binding_freq_dig4_`i'>aux5 if binding_freq_dig4_`i'!=. 
gen midconstr`i'= binding_freq_dig4_`i'>aux4 & binding_freq_dig4_`i'<=aux5  if binding_freq_dig4_`i'!=. 
gen lconstr`i'= binding_freq_dig4_`i'<aux4 if binding_freq_dig4_`i'!=. 

gen age_pos_constr`i'=age_pos*constr`i'
gen indagine_constr`i'=indagine*constr`i'

gen age_pos_midc`i'=age_pos*midconstr`i'
gen age_pos_mconstr`i'=age_pos*mconstr`i'
gen indagine_midc`i'=indagine*midconstr`i'
gen indagine_mconstr`i'=indagine*mconstr`i'

gen age_pos_freqc`i'=age_pos*binding_freq_dig4_`i'
gen age_pos_freqc_sq`i'=age_pos*(binding_freq_dig4_`i'^2)

drop aux* dig4_num
}
cap drop aux*
by ateco4: egen aux=seq()
corr binding_freq_dig4_1 binding_freq_dig4_9 if aux==1
drop aux

*Here I create an index of observations per ateco4 industry
bysort ateco4: egen ateco4_num=count(log_prod1!=.)
by ateco4: egen ateco4_seq=seq()








**************************************************
****** PART II, GENERATING THE RESULTS ***********
**************************************************
*SELECTS METHOD TO COMPUTE STANDARD ERRORS
*Note: to replicate the estimation methode used in the paper, choose option 1. Nonetheless option 2 yields similar standard errors and is faster
*option 1*
*global std_type="vce(bootstrap, reps(50000))"

*option 2* 
global std_type="robust"

*log using results, replace

foreach i in 2{

gen constr=constr`i'
gen age_pos_constr=age_pos_constr`i'
gen indagine_constr=indagine_constr`i'
gen age_pos_midc=age_pos_midc`i'
gen age_pos_mconstr=age_pos_mconstr`i'
gen age_pos_lc=age_pos*lconstr`i'
gen indagine_midc=indagine_midc`i'
gen indagine_mconstr=indagine_mconstr`i'
gen age_pos_freqc=age_pos_freqc`i'
gen age_pos_freqc_sq=age_pos_freqc_sq`i'

gen mconstr=mconstr2 
gen midc=midconstr2
gen lconstr=2-mconstr-midc

gen age_pos_1=age_pos*(age_pos<11) if age_pos>2
gen age_pos_2=age_pos*(age_pos>10)*(age_pos<21) if age_pos>2
gen age_pos_3=age_pos*(age_pos>20)*(age_pos<31) if age_pos>2
gen age_pos_4=age_pos*(age_pos>30)*(age_pos<41) if age_pos>2

gen age_pos_1_lconstr=age_pos_1*lconstr
gen age_pos_2_lconstr=age_pos_2*lconstr
gen age_pos_3_lconstr=age_pos_3*lconstr


gen age_pos_4_lconstr=age_pos_4*lconstr


gen age_pos_1_mconstr=age_pos_1*mconstr
gen age_pos_2_mconstr=age_pos_2*mconstr
gen age_pos_3_mconstr=age_pos_3*mconstr
gen age_pos_4_mconstr=age_pos_4*mconstr

gen age_pos_1_midc=age_pos_1*midc
gen age_pos_2_midc=age_pos_2*midc
gen age_pos_3_midc=age_pos_3*midc
gen age_pos_4_midc=age_pos_4*midc

 
 
*TABLE 1
quietly xtreg log_prod1 age_pos age_pos_constr i.indagine if age_pos>2 & age_pos<46 & nobs_firm>5,fe $std_type cluster(newcode)
estimates store m1
quietly xtreg log_prod1 age_pos age_pos_constr i.indagine i.indagine_constr if age_pos>2 & age_pos<46 & nobs_firm>5 ,fe $std_type cluster(newcode)
estimates store m2
quietly xtreg log_prod1 age_pos age_pos_midc age_pos_mconstr i.indagine if age_pos>2 & age_pos<46 & nobs_firm>5,fe $std_type cluster(newcode)
estimates store m3
quietly xtreg log_prod1 age_pos age_pos_midc age_pos_mconstr i.indagine i.indagine_mconstr i.indagine_midc  if age_pos>2 & age_pos<46 & nobs_firm>5,fe $std_type cluster(newcode)
estimates store m4
display "**************************************************"
display "Table 1"
display "**************************************************"
esttab m1 m2 m3 m4, ar2  star(* 0.1 ** 0.05 *** 0.001)




display "**************************************************"
display "Table 5 in the online Appendix (the estimated coefficients are used to construct Figure 1 in the paper)"
display "**************************************************"
xtreg log_prod1 age_pos_1 age_pos_2 age_pos_3 age_pos_4 age_pos_1_midc age_pos_2_midc age_pos_3_midc age_pos_4_midc  age_pos_1_mconstr age_pos_2_mconstr age_pos_3_mconstr age_pos_4_mconstr i.indagine if age_pos>0 & age_pos<41 & nobs_firm>5 ,fe $std_type cluster(newcode)

display "**************************************************"
display "Table 6 in the online Appendix (the estimated coefficients are used to construct Figure 2 in the paper)"
display "**************************************************"
xtreg log_prod1 age_pos age_pos_freqc age_pos_freqc_sq i.indagine if age_pos>2 & age_pos<46 & nobs_firm>5,fe $std_type cluster(newcode)
scalar b1=_b[age_pos_freqc]
scalar b2=_b[age_pos_freqc_sq]
centile binding_freq_dig4_`i', centile(1(1)100)
display "**************************************************"
display "coefficients for figure 2"
display "**************************************************"
display "Below are the differences between the constant value .021378 and productivity growth in each decile"
display "Substracting these values from 0.021378 yields the productivity growth values displayed in figure 2"
forvalues y = 5(10)95 {
display `y'
display b1*r(c_`y')+b2*(r(c_`y')^2)
}

display "**************************************************"
display "Table 8"
display "**************************************************"
quietly xtreg log_prod1 age_pos age_pos_constr i.indagine i.indagine_constr if age_pos>2 & age_pos<46 & nobs_firm>5 ,fe $std_type cluster(newcode)
estimates store m1
quietly xtreg log_prod1 age_pos age_pos_midc age_pos_mconstr i.indagine i.indagine_mconstr i.indagine_midc  if age_pos>2 & age_pos<46 & nobs_firm>5,fe $std_type cluster(newcode)
estimates store m2
quietly xtreg log_prod1 age_pos age_pos_constr i.indagine i.indagine_constr if age_pos>2 & age_pos<46 & nobs_firm>5 & binding_firm_raw==0,fe $std_type cluster(newcode)
estimates store m3
quietly xtreg log_prod1 age_pos age_pos_midc age_pos_mconstr i.indagine i.indagine_mconstr i.indagine_midc  if age_pos>2 & age_pos<46 & nobs_firm>5 & binding_firm_raw==0,fe $std_type cluster(newcode)
estimates store m4
esttab m1 m2 m3 m4, ar2  star(* 0.1 ** 0.05 *** 0.001)
drop constr age_pos_constr indagine_constr age_pos_midc age_pos_lc  age_pos_mconstr indagine_midc indagine_mconstr 
drop age_pos_freqc age_pos_freqc_sq

}





*Compute innovation variables
gen aux1=(r_d_np>0 & r_d_np!=. & randd==1 ) if firm2_indagine2!=.
gen rd_radical=aux1>0 & aux1!=. & rd_spending>0 & rd_spending!=. if firm2_indagine2!=.
gen rd_incremental=randd==1 & randd!=. & rd_radical==0  & rd_spending>0 & rd_spending!=. if firm2_indagine2!=.
gen inn_any=(rd_incremental==1 | rd_radical==1) if firm2_indagine2!=. & rd_radical!=. & rd_incremental!=.
display "**************************************************"
display "Table 3 (last 2 rows)"
display "**************************************************"
summ inn_any if lconstr1==1
summ inn_any if midconstr1==1
summ inn_any if mconstr1==1
summ binding_firm_raw if lconstr1==1 & firm2_indagine2!=.
summ binding_firm_raw if midconstr1==1 & firm2_indagine2!=.
summ binding_firm_raw if mconstr1==1 & firm2_indagine2!=.


*Compute patents per year
recode pat_granted .=0
recode mod_granted .=0
recode epo_n .=0
recode  max_citations .=0
gen pat_total=pat_granted+mod_granted
*pat total is probability to innovate over the whole 7 years period with patenting information
*pat total_adj is corresponding yearly probability
gen pat_total_adj=pat_total/7
gen epo_n_adj=epo_n/7
gen young=ageforind4<6
display "**************************************************"
display "Table 6"
display "**************************************************"
display "Panel A left (columns 1 and 2)"
summ pat_total_adj if indagine2==4 & constr2==1
summ pat_total_adj if indagine2==4 & ageforind4<6 & constr2==1
summ pat_total_adj if indagine2==4 & ageforind4<11 & constr2==1
summ pat_total_adj if indagine2==4 & ageforind4<21 & constr2==1
summ pat_total_adj if indagine2==4 & constr2==0
summ pat_total_adj if indagine2==4 & ageforind4<6 & constr2==0
summ pat_total_adj if indagine2==4 & ageforind4<11 & constr2==0
summ pat_total_adj if indagine2==4 & ageforind4<21 & constr2==0
display "Panel A left, column 3" 
oprobit pat_total constr2 if indagine2==4,robust
oprobit pat_total constr2 if indagine2==4 & ageforind4<6,robust
oprobit pat_total constr2 if indagine2==4 & ageforind4<11,robust
oprobit pat_total constr2 if indagine2==4 & ageforind4<21,robust
display "Panel B left (columns 1 and 2)"
summ epo_n_adj if indagine2==4 & constr2==1
summ epo_n_adj if indagine2==4 & ageforind4<6 & constr2==1
summ epo_n_adj if indagine2==4 & ageforind4<11 & constr2==1
summ epo_n_adj if indagine2==4 & ageforind4<21 & constr2==1
summ epo_n_adj if indagine2==4 & constr2==0
summ epo_n_adj if indagine2==4 & ageforind4<6 & constr2==0
summ epo_n_adj if indagine2==4 & ageforind4<11 & constr2==0
summ epo_n_adj if indagine2==4 & ageforind4<21 & constr2==0
display "Panel B left, column 3"
oprobit epo_n_adj constr2 if indagine2==4,robust
oprobit epo_n_adj constr2 if indagine2==4 & ageforind4<6,robust
oprobit epo_n_adj constr2 if indagine2==4 & ageforind4<11,robust
oprobit epo_n_adj constr2 if indagine2==4 & ageforind4<21,robust

gen radical=max_citations>5
*NOTE: radical innovation measured as 10 most cited patenting firms, as follows: 
* there are 516 firms with some patent at the EPO (count if epo_n>0 & indagine2==4)
* and 55 firms with a patent with 6 or more citations (count if max_citations>5 & indagine2==4)
gen epo_n_rad=radical*epo_n_adj
display "Panel B right (columns 1 and 2)"
summ epo_n_rad if indagine2==4 & constr2==1
summ epo_n_rad if indagine2==4 & ageforind4<6 & constr2==1
summ epo_n_rad if indagine2==4 & ageforind4<11 & constr2==1
summ epo_n_rad if indagine2==4 & ageforind4<21 & constr2==1
summ epo_n_rad if indagine2==4 & constr2==0
summ epo_n_rad if indagine2==4 & ageforind4<6 & constr2==0
summ epo_n_rad if indagine2==4 & ageforind4<11 & constr2==0
summ epo_n_rad if indagine2==4 & ageforind4<21 & constr2==0
display "Panel B right, column 3"
oprobit epo_n_rad constr2 if indagine2==4,robust
oprobit epo_n_rad constr2 if indagine2==4 & ageforind4<6,robust
oprobit epo_n_rad constr2 if indagine2==4 & ageforind4<11,robust
oprobit epo_n_rad constr2 if indagine2==4 & ageforind4<21,robust

display "**************************************************"
display "Table 7"
display "**************************************************"
display "Panel A left (columns 1 and 2)"
summ rd_radical if constr2==1
summ rd_radical if age<6 & constr2==1
summ rd_radical if age<11 & constr2==1
summ rd_radical if age<21 & constr2==1
summ rd_radical if constr2==0
summ rd_radical if age<6 & constr2==0
summ rd_radical if age<11 & constr2==0
summ rd_radical if age<21 & constr2==0
display "Panel A left, column 3 "
probit rd_radical constr2,robust
probit rd_radical constr2 if age<6,robust
probit rd_radical constr2 if age<11,robust
probit rd_radical constr2 if age<21,robust
display "Panel B left (columns 1 and 2)"
summ rd_incremental if constr2==1
summ rd_incremental if age<6 & constr2==1
summ rd_incremental if age<11 & constr2==1
summ rd_incremental if age<21 & constr2==1
summ rd_incremental if constr2==0
summ rd_incremental if age<6 & constr2==0
summ rd_incremental if age<11 & constr2==0
summ rd_incremental if age<21 & constr2==0
display "Panel B left, column 3" 
probit rd_incremental constr2,robust
probit rd_incremental constr2 if age<6,robust
probit rd_incremental constr2 if age<11,robust
probit rd_incremental constr2 if age<21,robust


*TABLE 7 of the online Appendix (each iteration of this loop displays 2 columns of the table)
foreach i in 1 3 4 9{

gen constr=constr`i'
gen age_pos_constr=age_pos_constr`i'
gen indagine_constr=indagine_constr`i'
gen age_pos_midc=age_pos_midc`i'
gen age_pos_mconstr=age_pos_mconstr`i'
gen indagine_midc=indagine_midc`i'
gen indagine_mconstr=indagine_mconstr`i'
gen age_pos_freqc=age_pos_freqc`i'
gen age_pos_freqc_sq=age_pos_freqc_sq`i'



quietly xtreg log_prod1 age_pos age_pos_constr i.indagine i.indagine_constr if age_pos>2 & age_pos<46 & nobs_firm>5 ,fe $std_type cluster(newcode)
estimates store m1
quietly xtreg log_prod1 age_pos age_pos_midc age_pos_mconstr i.indagine i.indagine_mconstr i.indagine_midc  if age_pos>2 & age_pos<46 & nobs_firm>5,fe $std_type cluster(newcode)
estimates store m2
esttab m1 m2, ar2  star(* 0.1 ** 0.05 *** 0.001)

drop constr age_pos_constr indagine_constr age_pos_midc age_pos_mconstr indagine_midc indagine_mconstr 
drop age_pos_freqc age_pos_freqc_sq

}

*TABLE 8 of the online Appendix 
foreach i in 12{

gen constr=constr`i'
gen age_pos_constr=age_pos_constr`i'
gen indagine_constr=indagine_constr`i'
gen age_pos_midc=age_pos_midc`i'
gen age_pos_mconstr=age_pos_mconstr`i'
gen indagine_midc=indagine_midc`i'
gen indagine_mconstr=indagine_mconstr`i'
gen age_pos_freqc=age_pos_freqc`i'
gen age_pos_freqc_sq=age_pos_freqc_sq`i'



quietly xtreg log_prod1 age_pos age_pos_constr i.indagine  if age_pos>2 & age_pos<46 & nobs_firm>5 ,fe $std_type cluster(newcode)
estimates store m1
quietly xtreg log_prod1 age_pos age_pos_midc age_pos_mconstr i.indagine  if age_pos>2 & age_pos<46 & nobs_firm>5,fe $std_type cluster(newcode)
estimates store m2
esttab m1 m2, ar2  star(* 0.1 ** 0.05 *** 0.001)

drop constr age_pos_constr indagine_constr age_pos_midc age_pos_mconstr indagine_midc indagine_mconstr 
drop age_pos_freqc age_pos_freqc_sq

}

*TABLE 9 of the online Appendix  (weighted regressions)
recode occupa 0=.
bysort firm: egen occupa_firm=mean(occupa)
gen size_weight=.
recode size_weight .=3.92 if occupa_firm<50 & occupa_firm!=. 
recode size_weight .=1.65 if occupa_firm>49 & occupa_firm<100
recode size_weight .=1.22 if occupa_firm>99 & occupa_firm<200
recode size_weight .=0.67 if occupa_firm>199 & occupa_firm<500
recode size_weight .=0.44 if occupa_firm>499 & occupa_firm<1000
recode size_weight .=0.39 if occupa_firm>999 & occupa_firm!=.
foreach i in 2{

gen constr=constr`i'
gen age_pos_constr=age_pos_constr`i'
gen indagine_constr=indagine_constr`i'
gen age_pos_midc=age_pos_midc`i'
gen age_pos_mconstr=age_pos_mconstr`i'
gen indagine_midc=indagine_midc`i'
gen indagine_mconstr=indagine_mconstr`i'
gen age_pos_freqc=age_pos_freqc`i'
gen age_pos_freqc_sq=age_pos_freqc_sq`i'


quietly xtreg log_prod1 age_pos age_pos_constr i.indagine [pweight=size_weight] if age_pos>2 & age_pos<46 & nobs_firm>5,fe robust cluster(newcode)
estimates store m1
quietly xtreg log_prod1 age_pos age_pos_constr i.indagine i.indagine_constr [pweight=size_weight] if age_pos>2 & age_pos<46 & nobs_firm>5,fe robust cluster(newcode)
estimates store m2
quietly xtreg log_prod1 age_pos age_pos_constr i.indagine i.indagine_constr [pweight=size_weight] if age_pos>2 & age_pos<46 & nobs_firm>5 & binding_firm_raw==0,fe robust cluster(newcode)
estimates store m3
quietly xtreg log_prod1 age_pos age_pos_midc age_pos_mconstr i.indagine [pweight=size_weight] if age_pos>2 & age_pos<46 & nobs_firm>5,fe robust cluster(newcode)
estimates store m4
quietly xtreg log_prod1 age_pos age_pos_midc age_pos_mconstr i.indagine i.indagine_mconstr i.indagine_midc [pweight=size_weight]   if age_pos>2 & age_pos<46 & nobs_firm>5,fe robust cluster(newcode)
estimates store m5
quietly xtreg log_prod1 age_pos age_pos_midc age_pos_mconstr i.indagine  i.indagine_mconstr i.indagine_midc [pweight=size_weight] if age_pos>2 & age_pos<46 & nobs_firm>5 & binding_firm_raw==0,fe robust cluster(newcode)
estimates store m6
esttab m1 m2 m3 m4 m5 m6, ar2  star(* 0.1 ** 0.05 *** 0.001)


drop constr age_pos_constr indagine_constr age_pos_midc age_pos_mconstr indagine_midc indagine_mconstr 
drop age_pos_freqc age_pos_freqc_sq

}

*TABLE 10 of the online Appendix  (deflated TFP)
foreach i in 2{

gen constr=constr`i'
gen age_pos_constr=age_pos_constr`i'
gen indagine_constr=indagine_constr`i'
gen age_pos_midc=age_pos_midc`i'
gen age_pos_mconstr=age_pos_mconstr`i'
gen indagine_midc=indagine_midc`i'
gen indagine_mconstr=indagine_mconstr`i'
gen age_pos_freqc=age_pos_freqc`i'
gen age_pos_freqc_sq=age_pos_freqc_sq`i'

 

quietly xtreg log_prod_defl age_pos age_pos_constr i.indagine if age_pos>2 & age_pos<46 & nobs_firm>5,fe $std_type cluster(newcode)
estimates store m1
quietly xtreg log_prod_defl age_pos age_pos_constr i.indagine i.indagine_constr if age_pos>2 & age_pos<46 & nobs_firm>5 ,fe $std_type cluster(newcode)
estimates store m2
quietly xtreg log_prod_defl age_pos age_pos_constr i.indagine i.indagine_constr if age_pos>2 & age_pos<46 & nobs_firm>5 & binding_firm_raw==0,fe $std_type cluster(newcode)
estimates store m3
quietly xtreg log_prod_defl age_pos age_pos_midc age_pos_mconstr i.indagine if age_pos>2 & age_pos<46 & nobs_firm>5,fe $std_type cluster(newcode)
estimates store m4
quietly xtreg log_prod_defl age_pos age_pos_midc age_pos_mconstr i.indagine i.indagine_mconstr i.indagine_midc  if age_pos>2 & age_pos<46 & nobs_firm>5,fe $std_type cluster(newcode)
estimates store m5
quietly xtreg log_prod_defl age_pos age_pos_midc age_pos_mconstr i.indagine i.indagine_mconstr i.indagine_midc  if age_pos>2 & age_pos<46 & nobs_firm>5 & binding_firm_raw==0,fe $std_type cluster(newcode)
estimates store m6
esttab m1 m2 m3 m4 m5 m6, ar2  star(* 0.1 ** 0.05 *** 0.001)



*FIGURE 2 in the online Appendix
xtreg log_prod1 age_pos age_pos_freqc age_pos_freqc_sq i.indagine if age_pos>2 & age_pos<46 & nobs_firm>5,fe $std_type cluster(newcode)

scalar b1=_b[age_pos_freqc]
scalar b2=_b[age_pos_freqc_sq]
centile binding_freq_dig4_`i', centile(1(1)100)


 forvalues y = 5(10)95 {
display `y'
display b1*r(c_`y')+b2*(r(c_`y')^2)

}
drop constr age_pos_constr indagine_constr age_pos_midc age_pos_mconstr indagine_midc indagine_mconstr 
drop age_pos_freqc age_pos_freqc_sq
}

*Table 11 in the online Appendix ( ITFPQ)
foreach i in 2{

gen constr=constr`i'
gen age_pos_constr=age_pos_constr`i'
gen indagine_constr=indagine_constr`i'
gen age_pos_midc=age_pos_midc`i'
gen age_pos_mconstr=age_pos_mconstr`i'
gen indagine_midc=indagine_midc`i'
gen indagine_mconstr=indagine_mconstr`i'
gen age_pos_freqc=age_pos_freqc`i'
gen age_pos_freqc_sq=age_pos_freqc_sq`i'

 

quietly xtreg log_prod_ITFPQ age_pos age_pos_constr i.indagine if age_pos>2 & age_pos<46 & nobs_firm>5,fe $std_type cluster(newcode)
estimates store m1
quietly xtreg log_prod_ITFPQ age_pos age_pos_constr i.indagine i.indagine_constr if age_pos>2 & age_pos<46 & nobs_firm>5 ,fe $std_type cluster(newcode)
estimates store m2
quietly xtreg log_prod_ITFPQ age_pos age_pos_constr i.indagine i.indagine_constr if age_pos>2 & age_pos<46 & nobs_firm>5 & binding_firm_raw==0,fe $std_type cluster(newcode)
estimates store m3
quietly xtreg log_prod_ITFPQ age_pos age_pos_midc age_pos_mconstr i.indagine if age_pos>2 & age_pos<46 & nobs_firm>5,fe $std_type cluster(newcode)
estimates store m4
quietly xtreg log_prod_ITFPQ age_pos age_pos_midc age_pos_mconstr i.indagine i.indagine_mconstr i.indagine_midc  if age_pos>2 & age_pos<46 & nobs_firm>5,fe $std_type cluster(newcode)
estimates store m5
quietly xtreg log_prod_ITFPQ age_pos age_pos_midc age_pos_mconstr i.indagine i.indagine_mconstr i.indagine_midc  if age_pos>2 & age_pos<46 & nobs_firm>5 & binding_firm_raw==0,fe $std_type cluster(newcode)
estimates store m6
esttab m1 m2 m3 m4 m5 m6, ar2  star(* 0.1 ** 0.05 *** 0.001)
drop constr age_pos_constr indagine_constr age_pos_midc age_pos_mconstr indagine_midc indagine_mconstr 
drop age_pos_freqc age_pos_freqc_sq
}

*Table 12 in the online Appendix (alternative measures)
*employment growth
preserve
drop if firm2_indagine2==.
foreach i in 2{

gen constr=constr`i'
gen age_pos_constr=age_pos_constr`i'
gen indagine_constr=indagine_constr`i'
gen age_pos_midc=age_pos_midc`i'
gen age_pos_mconstr=age_pos_mconstr`i'
gen indagine_midc=indagine_midc`i'
gen indagine_mconstr=indagine_mconstr`i'
gen age_pos_freqc=age_pos_freqc`i'
gen age_pos_freqc_sq=age_pos_freqc_sq`i'

tsset firm2 indagine2
*Panel A
quietly xtreg log_prod_occ age_pos age_pos_constr i.indagine i.indagine_constr if age_pos>2 & age_pos<46  ,fe $std_type cluster(firm2)
estimates store m1
quietly xtreg log_prod_occ age_pos age_pos_midc age_pos_mconstr i.indagine i.indagine_mconstr i.indagine_midc  if age_pos>2 & age_pos<46,fe $std_type cluster(firm2)
estimates store m2
esttab m1 m2, ar2  star(* 0.1 ** 0.05 *** 0.001)

*Panel B
quietly xtreg log_prod_occ age_pos age_pos_constr i.indagine i.indagine_constr if age_pos>2 & age_pos<46 & binding_firm_raw==0,fe $std_type cluster(firm2)
estimates store m1
quietly xtreg log_prod_occ age_pos age_pos_midc age_pos_mconstr i.indagine i.indagine_mconstr i.indagine_midc  if age_pos>2 & age_pos<46 & binding_firm_raw==0,fe $std_type cluster(firm2)
estimates store m2
esttab m1 m2, ar2  star(* 0.1 ** 0.05 *** 0.001)
drop constr age_pos_constr indagine_constr age_pos_midc age_pos_mconstr indagine_midc indagine_mconstr 
drop age_pos_freqc age_pos_freqc_sq
}
restore
*fixed capital growth
foreach i in 2{

gen constr=constr`i'
gen age_pos_constr=age_pos_constr`i'
gen indagine_constr=indagine_constr`i'
gen age_pos_midc=age_pos_midc`i'
gen age_pos_mconstr=age_pos_mconstr`i'
gen indagine_midc=indagine_midc`i'
gen indagine_mconstr=indagine_mconstr`i'
gen age_pos_freqc=age_pos_freqc`i'
gen age_pos_freqc_sq=age_pos_freqc_sq`i'


*Panel A
quietly xtreg log_cap age_pos age_pos_constr i.indagine i.indagine_constr if age_pos>2 & age_pos<46 & nobs_firm>5 ,fe $std_type cluster(newcode)
estimates store m1
quietly xtreg log_cap age_pos age_pos_midc age_pos_mconstr i.indagine i.indagine_mconstr i.indagine_midc  if age_pos>2 & age_pos<46 & nobs_firm>5,fe $std_type cluster(newcode)
estimates store m2
esttab m1 m2, ar2  star(* 0.1 ** 0.05 *** 0.001)

*Panel B
quietly xtreg log_cap age_pos age_pos_constr i.indagine i.indagine_constr if age_pos>2 & age_pos<46 & nobs_firm>5 & binding_firm_raw==0,fe $std_type cluster(newcode)
estimates store m1
quietly xtreg log_cap age_pos age_pos_midc age_pos_mconstr i.indagine i.indagine_mconstr i.indagine_midc  if age_pos>2 & age_pos<46 & nobs_firm>5 & binding_firm_raw==0,fe $std_type cluster(newcode)
estimates store m2
esttab m1 m2, ar2  star(* 0.1 ** 0.05 *** 0.001)

drop constr age_pos_constr indagine_constr age_pos_midc age_pos_mconstr indagine_midc indagine_mconstr 
drop age_pos_freqc age_pos_freqc_sq

}
*labour productivity growth
foreach i in 2{

gen constr=constr`i'
gen age_pos_constr=age_pos_constr`i'
gen indagine_constr=indagine_constr`i'
gen age_pos_midc=age_pos_midc`i'
gen age_pos_mconstr=age_pos_mconstr`i'
gen indagine_midc=indagine_midc`i'
gen indagine_mconstr=indagine_mconstr`i'
gen age_pos_freqc=age_pos_freqc`i'
gen age_pos_freqc_sq=age_pos_freqc_sq`i'


*Panel A
quietly xtreg log_prod_LP age_pos age_pos_constr i.indagine i.indagine_constr if age_pos>2 & age_pos<46 & nobs_firm>5 ,fe $std_type cluster(newcode)
estimates store m1
quietly xtreg log_prod_LP age_pos age_pos_midc age_pos_mconstr i.indagine i.indagine_mconstr i.indagine_midc  if age_pos>2 & age_pos<46 & nobs_firm>5,fe $std_type cluster(newcode)
estimates store m2
esttab m1 m2, ar2  star(* 0.1 ** 0.05 *** 0.001)

*Panel B
quietly xtreg log_prod_LP age_pos age_pos_constr i.indagine i.indagine_constr if age_pos>2 & age_pos<46 & nobs_firm>5 & binding_firm_raw==0,fe $std_type cluster(newcode)
estimates store m1
quietly xtreg log_prod_LP age_pos age_pos_midc age_pos_mconstr i.indagine i.indagine_mconstr i.indagine_midc  if age_pos>2 & age_pos<46 & nobs_firm>5 & binding_firm_raw==0,fe $std_type cluster(newcode)
estimates store m2
esttab m1 m2, ar2  star(* 0.1 ** 0.05 *** 0.001)

drop constr age_pos_constr indagine_constr age_pos_midc age_pos_mconstr indagine_midc indagine_mconstr 
drop age_pos_freqc age_pos_freqc_sq

}


*Table 13 in the online Appendix - INNOVATION AND VOLATILITY OF PRODUCTIVITY
tsset firm2 indagine2
xtreg log_prod1_sd rd_radical if firm2_indagine2!=. & log_prod1_sd<0.5,fe robust
xtreg log_prod1_sd rd_radical if firm2_indagine2!=. & age<11 & log_prod1_sd<0.5,fe robust
xtreg log_prod1_sd rd_radical if firm2_indagine2!=. & age<21 & log_prod1_sd<0.5,fe robust
xtreg log_prod1_sd rd_incremental if firm2_indagine2!=. & log_prod1_sd<0.5,fe robust
xtreg log_prod1_sd rd_incremental if firm2_indagine2!=. & age<11 & log_prod1_sd<0.5,fe robust
xtreg log_prod1_sd rd_incremental if firm2_indagine2!=. & age<21 & log_prod1_sd<0.5,fe robust
xtreg log_prod1_sd rd_radical if firm2_indagine2!=. & log_prod1_sd<0.5 & randd==1 & rd_spending>0   & rd_spending!=.,fe robust
xtreg log_prod1_sd rd_radical if firm2_indagine2!=. & age<11 & log_prod1_sd<0.5 & randd==1 & rd_spending>0  & rd_spending!=.,fe robust
xtreg log_prod1_sd rd_radical if firm2_indagine2!=. & age<21 & log_prod1_sd<0.5 & randd==1 & rd_spending>0  & rd_spending!=.,fe robust
xtreg log_prod1_sd rd_incremental if firm2_indagine2!=. & log_prod1_sd<0.5 & randd==1 & rd_spending>0  & rd_spending!=.,fe robust
xtreg log_prod1_sd rd_incremental if firm2_indagine2!=. & age<11 & log_prod1_sd<0.5 & randd==1 & rd_spending>0 &  rd_spending!=.,fe robust
xtreg log_prod1_sd rd_incremental if firm2_indagine2!=. & age<21 & log_prod1_sd<0.5 & randd==1 & rd_spending>0 &  rd_spending!=.,fe robust


*Table 17 in the online Appendix
cap drop aux*
gen size_g=.
egen aux=pctile(occupa) if occupa!=. & occupa!=0 & indagine2==4, p(20)
recode size_g .=1 if occupa<aux & occupa!=. & occupa!=0 & indagine2==4
egen aux1=pctile(occupa) if occupa!=. & occupa!=0 & indagine2==4, p(40)
recode size_g .=2 if occupa>aux & occupa<aux1 & occupa!=. & occupa!=0 & indagine2==4
egen aux2=pctile(occupa) if occupa!=. & occupa!=0 & indagine2==4, p(60)
recode size_g .=3 if occupa>aux1 & occupa<aux2 & occupa!=. & occupa!=0 & indagine2==4
egen aux3=pctile(occupa) if occupa!=. & occupa!=0 & indagine2==4, p(80)
recode size_g .=4 if occupa>aux2 & occupa<aux3 & occupa!=. & occupa!=0 & indagine2==4
recode size_g .=5 if occupa>aux3 & occupa!=. & occupa!=0 & indagine2==4
drop aux*
preserve
keep if constr2==1
bysort size_g: egen aux1=mean(pat_total_adj) 
by size_g: egen aux2=mean(occupa) if occupa!=. & occupa!=0
by size_g: gen aux3=aux1/aux2*100
by size_g: summ aux3
drop aux*
restore
preserve
keep if constr2==0
bysort size_g: egen aux1=mean(pat_total_adj) 
by size_g: egen aux2=mean(occupa) if occupa!=. & occupa!=0
by size_g: gen aux3=aux1/aux2*100
by size_g: summ aux3
drop aux*
restore
preserve
keep if constr2==1
bysort size_g: egen aux1=mean(epo_n_adj) 
by size_g: egen aux2=mean(occupa) if occupa!=. & occupa!=0
by size_g: gen aux3=aux1/aux2*100
by size_g: summ aux3
drop aux*
restore
preserve
keep if constr2==0
bysort size_g: egen aux1=mean(epo_n_adj) 
by size_g: egen aux2=mean(occupa) if occupa!=. & occupa!=0
by size_g: gen aux3=aux1/aux2*100
by size_g: summ aux3
drop aux*
restore
preserve
keep if constr2==1
bysort size_g: egen aux1=mean(epo_n_rad) 
by size_g: egen aux2=mean(occupa) if occupa!=. & occupa!=0
by size_g: gen aux3=aux1/aux2*100
by size_g: summ aux3
drop aux*
restore
preserve
keep if constr2==0
bysort size_g: egen aux1=mean(epo_n_rad) 
by size_g: egen aux2=mean(occupa) if occupa!=. & occupa!=0
by size_g: gen aux3=aux1/aux2*100
by size_g: summ aux3
drop aux*
restore


*Table 18 in the online Appendix
cap drop aux*
drop size*
reg log_prod1 i.indagine,robust
predict aux0 if firm2_indagine2!=.,res
gen occupa_r=occupa
drop occupa
gen occupa=aux0
gen size_g=.
egen aux=pctile(occupa) if occupa!=. & occupa!=0 & indagine2==4, p(20)
recode size_g .=1 if occupa<aux & occupa!=. & occupa!=0 & indagine2==4
egen aux1=pctile(occupa) if occupa!=. & occupa!=0 & indagine2==4, p(40)
recode size_g .=2 if occupa>aux & occupa<aux1 & occupa!=. & occupa!=0 & indagine2==4
egen aux2=pctile(occupa) if occupa!=. & occupa!=0 & indagine2==4, p(60)
recode size_g .=3 if occupa>aux1 & occupa<aux2 & occupa!=. & occupa!=0 & indagine2==4
egen aux3=pctile(occupa) if occupa!=. & occupa!=0 & indagine2==4, p(80)
recode size_g .=4 if occupa>aux2 & occupa<aux3 & occupa!=. & occupa!=0 & indagine2==4
recode size_g .=5 if occupa>aux3 & occupa!=. & occupa!=0 & indagine2==4
drop aux*
*unconditional
bysort size_g: summ pat_total_adj if constr2==1
bysort size_g: summ pat_total_adj if constr2==0
bysort size_g: summ epo_n_adj if constr2==1
bysort size_g: summ epo_n_adj if constr2==0
bysort size_g: summ epo_n_rad if constr2==1
bysort size_g: summ epo_n_rad if constr2==0



*Table 19 in the online Appendix
bysort firm: egen aux=mean(randd)
gen some_randd=aux>0 & aux!=.
cap drop aux*
bysort firm: egen aux=mean(pat_total)
bysort firm: egen aux1=mean(pat_filed)
bysort firm: egen aux2=mean(epo_n)
gen some_patents=(aux+aux1+aux2)>0 
drop aux*
tsset firm indagine
foreach i in 2{

gen constr=constr`i'
gen age_pos_constr=age_pos_constr`i'
gen indagine_constr=indagine_constr`i'
gen age_pos_midc=age_pos_midc`i'
gen age_pos_mconstr=age_pos_mconstr`i'
gen indagine_midc=indagine_midc`i'
gen indagine_mconstr=indagine_mconstr`i'
gen age_pos_freqc=age_pos_freqc`i'
gen age_pos_freqc_sq=age_pos_freqc_sq`i'


quietly xtreg log_prod1 age_pos age_pos_constr i.indagine i.indagine_constr if age_pos>2 & age_pos<46 & nobs_firm>5,fe $std_type cluster(newcode)
estimates store m1
quietly xtreg log_prod1 age_pos age_pos_constr i.indagine i.indagine_constr if age_pos>2 & age_pos<46 & nobs_firm>5 & some_randd==0 & some_patents==0,fe $std_type cluster(newcode)
estimates store m2
quietly xtreg log_prod1 age_pos age_pos_midc age_pos_mconstr i.indagine i.indagine_mconstr i.indagine_midc  if age_pos>2 & age_pos<46 & nobs_firm>5,fe $std_type cluster(newcode)
estimates store m3
quietly xtreg log_prod1 age_pos age_pos_midc age_pos_mconstr i.indagine i.indagine_mconstr i.indagine_midc  if age_pos>2 & age_pos<46 & nobs_firm>5 & some_randd==0 & some_patents==0,fe $std_type cluster(newcode)
estimates store m4

esttab m1 m2 m3 m4, ar2  star(* 0.1 ** 0.05 *** 0.001)
*esttab m1 m2 m3 m4 m5 m6 using model1ver9c.csv, ar2 star(* 0.1 ** 0.05 *** 0.001)


}



*log close
